==> ja-xdtp-1.1.4.tbz: include/xdtp/XDTPTransform.h <==
/* 
 * $Id: XDTPTransform.h,v 1.3 2005/10/17 10:18:36 ozawa Exp $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.3 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___XDTPTRANSFORM_H
#define ___XDTPTRANSFORM_H

#include "XDTPObjectWrapper.h"
#include "modules/XDTPModuleLoader.h"

#include "libxslt/transform.h"

namespace XDTP {

typedef enum {
    OBJECT_TYPE_USTRING = 0,
    OBJECT_TYPE_XSL,
    OBJECT_TYPE_MC,
    OBJECT_TYPE_XDTP_EXT_MODULE,    // ݥ⥸塼()
    OBJECT_TYPE_XDTP_EXT_CHECKER,   // ݥ⥸塼()
    OBJECT_TYPE_XDTP_LCL_MODULE,    // ݥ⥸塼()
    OBJECT_TYPE_XDTP_LCL_CHECKER,   // ݥ⥸塼()
} OBJECT_TYPES;

typedef struct {
    XDTPModule  *module;
    XDTPChecker *checker;
} XDTP_MC;

typedef std::list<XDTPModuleLibrary*>   LibraryList;

class XDTPTransform
{
public:
    XDTPTransform();
    virtual ~XDTPTransform();
    
    /**
     * Ԥޤ
     *  set/get ϤΥ᥽åɤѤ뤳Ȥ򤱤Ƥ
     * Ѵ set/get ϥ᥽åɤѤ뤳ȤϤǤޤ
     * 
     * @return  true ᤷޤ
     */
    bool initialize();
    
    /**
     * ֥ȤԤޤ
     * Ѵ塢֥ȤѤ뤳Ȥʤ䡢֤ѹ
     * ϡ˸ƤӽФɬפޤ
     */
    void uninitialize();
    
    /**
     * Ѵ¹Ԥޤ
     * 
     * @param anInput ѴXMLե
     * @param anOutput եʴ¸ΥեϾ񤭤ޤ
     * @return Ѵ true ᤷޤ
     */
    bool transform(const Glib::ustring& anInput, const Glib::ustring& anOutput);
    
    /**
     * Ѵȯ顼åϤޤ
     * 顼ȯʤäϡɽޤ
     * 
     * @param out 
     */
    void showErrorMsg(FILE* out = stdout);
    
    /**
     * XMLʸϤå򥹥åפޤ
     * 
     * @param bCheck åפ true ꤷޤ
     */
    void skipXMLCheck(bool bCheck);
    
    /**
     * XMLʸϤå򥹥åפ뤫Ĵ٤ޤ
     * 
     * @return åפ true ᤷޤ
     */
    bool isXMLCheck();
    
    /**
     * ѴXSLեɲäޤ
     * 
     * @param aPath XSLեؤΥѥ
     * @param useOutputType ե뤬ϷݻѤ true ꤷޤ
     */
    void addXSLFile(const Glib::ustring& aPath, bool useOutputType);
    
    /**
     * ѴXSL֥Ȥɲäޤ
     * 
     * @param aXSL XSL֥
     * @param useOutputType ֥ȤϷݻѤ true ꤷޤ
     */
    void addXSLObject(xsltStylesheetPtr aXSL, bool useOutputType);
    
    /**
     * ѴXSLեΰ򥯥ꥢޤ
     */
    void clearXSLFile();
    
    /**
     * ѴXSLեΰޤ
     * 
     * @deprecated
     * @return ѴXSLեΰ
     */
    const StringList& getXSLFileList();

    /**
     * ѴXSLե뤪ӥ֥Ȥΰޤ
     * 
     * @return ѴXSLե뤪ӥ֥Ȥΰ
     */
    const XDTPObjectWrapper& getXSLList();

    /**
     * ѴXDTP⥸塼ɲäޤ
     * 
     * @param aPath XDTP⥸塼ؤΥѥ
     */
    void addXDTPModule(const Glib::ustring& aPath);

    /**
     * ѴXDTP⥸塼ɲäޤ
     * 
     * @param aModule XDTP⥸塼
     * @param aChecker XDTPåѤʤ NULL Ǥޤ
     */
    void addXDTPModule(XDTPModule *aModule, XDTPChecker *aChecker);

    /**
     * ѴXDTP⥸塼򥯥ꥢޤ
     */
    void clearXDTPModule();
    
    /**
     * ѴXDTP⥸塼ΰޤ
     * 
     * @deprecated
     * @return ѴXDTP⥸塼ΰ
     */
    const StringList& getXDTPModuleList();

    /**
     * ѴXDTP⥸塼ΰޤ
     * 
     * @return ѴXDTP⥸塼ΰ
     */
    const XDTPObjectWrapper& getXDTPMCList();

    /**
     * ѴXDTP⥸塼ؤΥץɲäޤ
     * 
     * @param anOption ɲåץ
     */
    void addOption(const Glib::ustring& anOption);

    /**
     * ѴXDTP⥸塼ؤΥץ򥯥ꥢޤ
     */
    void clearOption();
    
    /**
     * ѴXDTP⥸塼ؤΥץΰޤ
     * 
     * @return ѴXDTP⥸塼ؤΥץΰ
     */
    const StringList& getOptionList();

    /**
     * Ϸꤷޤ
     * 
     * @param aType Ϸ
     */
    void setOutputType(const Glib::ustring& aType);

    /**
     * Ϸޤ
     * 
     * @return Ϸ
     */
    const Glib::ustring& getOutputType();

    /**
     * åɽ٥ꤷޤ
     * 
     * @param aMode åɽ٥
     */
    void setVerboseMode(int aMode);
    
    /**
     * åɽ٥ޤ
     */
    int getVerboseMode();

    /**
     * ϥեΥ󥳡ɤꤷޤ
     * 
     * @param anEncoding ϥեΥ󥳡
     */
    void setInputEncoding(const Glib::ustring& anEncoding);

    /**
     * ϥեΥ󥳡ɤޤ
     * 
     * @return ϥեΥ󥳡
     */
    const Glib::ustring& getInputEncoding();
    
    /**
     * ϥեΥ󥳡ɤꤷޤ
     * 
     * @param anEncoding ϥեΥ󥳡
     */
    void setOutputEncoding(const Glib::ustring& anEncoding);

    /**
     * ϥեΥ󥳡ɤޤ
     * 
     * @return ϥեΥ󥳡
     */
    const Glib::ustring& getOutputEncoding();

public:
    /**
     * 顼åꤷޤ
     * 
     * @param aMsg 顼å
     */
    void setErrorMsg(const Glib::ustring& aMsg);

private:
    bool loadModules(LibraryList& libraries,
                     XDTPObjectWrapper& modules, XDTPObjectWrapper& checkers);
    void unloadModules(LibraryList& libraries,
                       XDTPObjectWrapper& modules, XDTPObjectWrapper& checkers);
    bool loadLocalModule(const Glib::ustring& module,
                         XDTPObjectWrapper& modules, XDTPObjectWrapper& checkers);

    xsltStylesheetPtr parseXSL(int pos);

private:
    XDTPObjectWrapper   m_XSLObjects;
    int                 m_XSL4OutputPos;
    XDTPObjectWrapper   m_XDTPModules;
    StringList          m_OptionList;
    bool                m_bSkipXMLCheck;
    int                 m_nVerbose;
    Glib::ustring       m_OutputType;
    Glib::ustring       m_InputEncoding;
    Glib::ustring       m_OutputEncoding;
    
    Glib::ustring       m_ErrorMsg;

    LibraryList         m_libraries;
    XDTPObjectWrapper   m_modules;
    XDTPObjectWrapper   m_checkers;

private:
    StringList      __m_XSLFileList;    // deprecated
    StringList      __m_XDTPModuleList; // deprecated
};

};

#endif

==> ja-xdtp-1.3.1_4.tbz: include/xdtp/XDTPTransform.h <==
/* 
 * $Id: XDTPTransform.h,v 1.5 2006/06/29 07:26:42 ozawa Exp $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.5 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___XDTPTRANSFORM_H
#define ___XDTPTRANSFORM_H

#include "XDTPObjectWrapper.h"
#include "modules/XDTPModuleLoader.h"

#include "libxslt/transform.h"

namespace XDTP {

typedef enum {
    OBJECT_TYPE_USTRING = 0,
    OBJECT_TYPE_XSL,
    OBJECT_TYPE_MC,
    OBJECT_TYPE_XDTP_EXT_MODULE,    // ݥ⥸塼()
    OBJECT_TYPE_XDTP_EXT_CHECKER,   // ݥ⥸塼()
    OBJECT_TYPE_XDTP_LCL_MODULE,    // ݥ⥸塼()
    OBJECT_TYPE_XDTP_LCL_CHECKER,   // ݥ⥸塼()
} OBJECT_TYPES;

typedef struct {
    XDTPModule  *module;
    XDTPChecker *checker;
} XDTP_MC;

typedef std::list<XDTPModuleLibrary*>   LibraryList;

class XDTPTransform
{
public:
    XDTPTransform();
    virtual ~XDTPTransform();
    
    /**
     * Ԥޤ
     *  set/get ϤΥ᥽åɤѤ뤳Ȥ򤱤Ƥ
     * Ѵ set/get ϥ᥽åɤѤ뤳ȤϤǤޤ
     * 
     * @return  true ᤷޤ
     */
    bool initialize();
    
    /**
     * ֥ȤԤޤ
     * Ѵ塢֥ȤѤ뤳Ȥʤ䡢֤ѹ
     * ϡ˸ƤӽФɬפޤ
     */
    void uninitialize();
    
    /**
     * Ѵ¹Ԥޤ
     * 
     * @param anInput ѴXMLե
     * @param anOutput եʴ¸ΥեϾ񤭤ޤ
     * @return Ѵ true ᤷޤ
     */
    bool transform(const Glib::ustring& anInput, const Glib::ustring& anOutput);
    
    /**
     * Ѵȯ顼åϤޤ
     * 顼ȯʤäϡɽޤ
     * 
     * @param out 
     */
    void showErrorMsg(FILE* out = stdout) const;
    
    /**
     * XMLʸϤå򥹥åפޤ
     * 
     * @param bCheck åפ true ꤷޤ
     */
    void skipXMLCheck(bool bCheck);
    
    /**
     * XMLʸϤå򥹥åפ뤫Ĵ٤ޤ
     * 
     * @return åפ true ᤷޤ
     */
    bool isXMLCheck() const;
    
    /**
     * ѴXSLեɲäޤ
     * 
     * @param aPath XSLեؤΥѥ
     * @param useOutputType ե뤬ϷݻѤ true ꤷޤ
     */
    void addXSLFile(const Glib::ustring& aPath, bool useOutputType);
    
    /**
     * ѴXSL֥Ȥɲäޤ
     * 
     * @param aXSL XSL֥
     * @param useOutputType ֥ȤϷݻѤ true ꤷޤ
     */
    void addXSLObject(xsltStylesheetPtr aXSL, bool useOutputType);
    
    /**
     * ѴXSLեΰ򥯥ꥢޤ
     */
    void clearXSLFile();
    
    /**
     * ѴXSLեΰޤ
     * 
     * @deprecated
     * @return ѴXSLեΰ
     */
    const StringList& getXSLFileList();

    /**
     * ѴXSLե뤪ӥ֥Ȥΰޤ
     * 
     * @return ѴXSLե뤪ӥ֥Ȥΰ
     */
    const XDTPObjectWrapper& getXSLList() const;

    /**
     * ѴXDTP⥸塼ɲäޤ
     * 
     * @param aPath XDTP⥸塼ؤΥѥ
     */
    void addXDTPModule(const Glib::ustring& aPath);

    /**
     * ѴXDTP⥸塼ɲäޤ
     * 
     * @param aModule XDTP⥸塼
     * @param aChecker XDTPåѤʤ NULL Ǥޤ
     */
    void addXDTPModule(XDTPModule *aModule, XDTPChecker *aChecker);

    /**
     * ѴXDTP⥸塼򥯥ꥢޤ
     */
    void clearXDTPModule();
    
    /**
     * ѴXDTP⥸塼ΰޤ
     * 
     * @deprecated
     * @return ѴXDTP⥸塼ΰ
     */
    const StringList& getXDTPModuleList();

    /**
     * ѴXDTP⥸塼ΰޤ
     * 
     * @return ѴXDTP⥸塼ΰ
     */
    const XDTPObjectWrapper& getXDTPMCList() const;

    /**
     * ѴXDTP⥸塼ؤΥץɲäޤ
     * 
     * @param anOption ɲåץ
     */
    void addOption(const Glib::ustring& anOption);

    /**
     * ѴXDTP⥸塼ؤΥץ򥯥ꥢޤ
     */
    void clearOption();
    
    /**
     * ѴXDTP⥸塼ؤΥץΰޤ
     * 
     * @return ѴXDTP⥸塼ؤΥץΰ
     */
    const StringList& getOptionList() const;

    /**
     * Ϸꤷޤ
     * 
     * @param aType Ϸ
     */
    void setOutputType(const Glib::ustring& aType);

    /**
     * Ϸޤ
     * 
     * @return Ϸ
     */
    const Glib::ustring& getOutputType() const;

    /**
     * åɽ٥ꤷޤ
     * 
     * @param aMode åɽ٥
     */
    void setVerboseMode(int aMode);
    
    /**
     * åɽ٥ޤ
     */
    int getVerboseMode() const;

    /**
     * ϥեΥ󥳡ɤꤷޤ
     * 
     * @param anEncoding ϥեΥ󥳡
     */
    void setInputEncoding(const Glib::ustring& anEncoding);

    /**
     * ϥեΥ󥳡ɤޤ
     * 
     * @return ϥեΥ󥳡
     */
    const Glib::ustring& getInputEncoding() const;
    
    /**
     * ϥեΥ󥳡ɤꤷޤ
     * 
     * @param anEncoding ϥեΥ󥳡
     */
    void setOutputEncoding(const Glib::ustring& anEncoding);

    /**
     * ϥեΥ󥳡ɤޤ
     * 
     * @return ϥեΥ󥳡
     */
    const Glib::ustring& getOutputEncoding() const;

public:
    /**
     * 顼åꤷޤ
     * 
     * @param aMsg 顼å
     */
    void setErrorMsg(const Glib::ustring& aMsg);

private:
    bool loadModules(LibraryList& libraries,
                     XDTPObjectWrapper& modules, XDTPObjectWrapper& checkers);
    void unloadModules(LibraryList& libraries,
                       XDTPObjectWrapper& modules, XDTPObjectWrapper& checkers);
    bool loadLocalModule(const Glib::ustring& module,
                         XDTPObjectWrapper& modules, XDTPObjectWrapper& checkers);

    xsltStylesheetPtr parseXSL(int pos);

private:
    XDTPObjectWrapper   m_XSLObjects;
    int                 m_XSL4OutputPos;
    XDTPObjectWrapper   m_XDTPModules;
    StringList          m_OptionList;
    bool                m_bSkipXMLCheck;
    int                 m_nVerbose;
    Glib::ustring       m_OutputType;
    Glib::ustring       m_InputEncoding;
    Glib::ustring       m_OutputEncoding;
    mode_t				m_OutputMask;
    
    Glib::ustring       m_ErrorMsg;

    LibraryList         m_libraries;
    XDTPObjectWrapper   m_modules;
    XDTPObjectWrapper   m_checkers;

private:
    StringList      __m_XSLFileList;    // deprecated
    StringList      __m_XDTPModuleList; // deprecated
};

};

#endif
